@@ -1,4 +1,4 @@
--- $Id: stored.sql 41248 2014-03-31 11:56:32Z wsl $
+-- $Id: stored.sql 42198 2014-09-10 13:24:54Z wsl $
 -- $URL: https://svn.uvt.nl/its-id/trunk/sources/kiki/doc/stored.sql $
 
 \encoding UTF8
@@ -45,7 +45,7 @@ CREATE OR REPLACE FUNCTION internalize_domain(IN v TEXT) RETURNS VOID AS $$
 			SELECT INTO aa, p mail_alias, person FROM mail_aliases JOIN domains USING (domain)
 				WHERE domains.domain = d AND lower(mail_aliases.name) = lower(l);
 			IF NOT FOUND THEN
-				INSERT INTO mail_aliases (name, domain) VALUES (l, d) RETURNING mail_alias INTO aa;
+				INSERT INTO mail_aliases (name, domain, addressbook) VALUES (l, d, FALSE) RETURNING mail_alias INTO aa;
 				p := NULL;
 				RAISE WARNING 'While internalizing domain "%": "%" is mentioned as a destination for an alias and was created as a placeholder without any destinations. You MUST supply destinations yourself.', v, m;
 			END IF;
@@ -274,7 +274,7 @@ CREATE OR REPLACE FUNCTION create_personal_alias(ianr BIGINT, ialias TEXT) RETUR
 				UPDATE personal_destinations SET person = ianr WHERE mail_alias = m AND person = a;
 			END IF;
 		ELSE
-			INSERT INTO mail_aliases (name, domain, person) VALUES (l, d, ianr)
+			INSERT INTO mail_aliases (name, domain, addressbook, person) VALUES (l, d, FALSE, ianr)
 				RETURNING mail_alias INTO m;
 			INSERT INTO personal_destinations (mail_alias, person) VALUES (m, ianr);
 		END IF;
